SystemOrganization addCategory: #'Seaside-Pharo-Tools-Spec'!

ComposableModel subclass: #WAPharoServerAdapterSpecBrowser
	instanceVariableNames: 'listModel textModel toolbarModel adaptor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Pharo-Tools-Spec'!

!WAPharoServerAdapterSpecBrowser commentStamp: 'SvenVanCaekenberghe 5/24/2017 13:01' prior: 0!
I am WAPharoServerAdapterSpecBrowser, the Seaside Control Panel for Pharo.
	
I offer a UI to manage - add, remove, start & stop - Seaside adaptors.

A Seaside adaptor is the interface between an HTTP server and Seaside itself, representing a running web application server.

	WAPharoServerAdapterSpecBrowser open!

!WAPharoServerAdapterSpecBrowser class methodsFor: 'specs' stamp: 'JohanBrichau 2/7/2014 09:47'!
defaultSpec
	<spec>
	| delta |
	delta := 15.
	^ SpecLayout composed 
			add: #listModel origin: 0@0 corner: 1@0.5 offsetOrigin: 0@0 offsetCorner: 0@(delta negated);
			add: #toolbarModel origin: 0@0.5 corner: 1@0.5 offsetOrigin: 0@(delta negated) offsetCorner: 0@delta;
			add: #textModel origin: 0@0.5 corner: 1@1 offsetOrigin: 0@delta offsetCorner: 0@0;
			yourself! !

!WAPharoServerAdapterSpecBrowser class methodsFor: 'specs' stamp: 'SvenVanCaekenberghe 5/24/2017 14:11'!
menuCommandOn: aBuilder
	<worldMenu>

	(aBuilder item: #ServerAdapterBrowser)
		order: 0.21;
		parent: #Tools;
		label: 'Seaside Control Panel';
		icon: #seasideAdaptorRunningIcon asIcon;
		action: [ self open ]! !

!WAPharoServerAdapterSpecBrowser class methodsFor: 'example' stamp: 'pmm 9/13/2013 15:23'!
open
	"self open"
	WAPharoServerAdapterSpecBrowser new openWithSpec
! !

!WAPharoServerAdapterSpecBrowser class methodsFor: 'specs' stamp: 'StephanEggermont 8/31/2012 14:50'!
title
	^'Seaside Control Panel'! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'api' stamp: 'SvenVanCaekenberghe 5/24/2017 13:02'!
aboutText
	^ 'I am the Seaside Control Panel for Pharo. 
	
I offer a UI to manage - add, remove, start & stop - Seaside adaptors.

A Seaside adaptor is the interface between an HTTP server and Seaside itself, representing a running web application server.

My implementation class is WAPharoServerAdaptorSpecBrowser.'! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - accessing' stamp: 'StephanEggermont 8/31/2012 16:50'!
adapters: aList
	self listModel items: aList! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'accessing' stamp: 'pmm 9/13/2013 15:11'!
adaptor
	^ adaptor! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - accessing' stamp: 'JohanBrichau 6/18/2014 20:44'!
adaptorClasses
	^ (WAServerAdaptor allSubclasses reject: [ :each | each isAbstract ])
		asSortedCollection: [ :a :b | a name < b name ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - accessing' stamp: 'SvenVanCaekenberghe 5/24/2017 15:12'!
adaptorDescription
	^ String streamContents: [ :stream |
			stream 
				nextPutAll: 'Type: '; nextPutAll: adaptor class name; cr;
				nextPutAll: 'Port: '; nextPutAll: adaptor port greaseString; cr;
				nextPutAll: 'Encoding: '; nextPutAll: adaptor codec name; cr.
			adaptor additionalStatusOn: stream.
			stream nextPutAll: adaptor statusString ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/24/2017 12:42'!
adaptorsMenu: aMenu 
	^ MenuModel new
		addGroup: [ :group | 
			group addItem: [ :item |				 
				item 
					name: 'Add adaptor...';					
					action: [ self addAdaptor ] ].
			group addItem: [ :item |
				item 
					name: 'Remove adaptor';
					enabled: [ self hasSelectedAdaptor ];	
					action: [ self removeAdaptor: self listModel selectedItem ] ] ];
		addGroup: [ :group | 
			group addItem: [ :item |
				item 
					name: 'Set adaptor encoding...';
					enabled: [ self hasSelectedAdaptor ];	
					action: [ self setEncodingFor: self listModel selectedItem ] ] ];
		addGroup: [ :group | 
			group addItem: [ :item |
				item 
					name: 'Clear configuration caches';
					action: [ self clearConfigurationCaches ] ].
			group addItem: [ :item |
				item 
					name: 'Clear sessions';
					action: [ self clearSessions ] ] ];
		buildWithSpecAsPopup! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:46'!
addAdaptor
	| allAdaptors class port |
	allAdaptors := self adaptorClasses.
	class := UIManager default
		chooseFrom: (allAdaptors collect: [ :e | e name ])
		values: allAdaptors
		lines: #()
		title: 'Add Seaside Adaptor' translated.
	class
		ifNotNil: [ 
			port := UIManager default 
				request: 'Enter a port number' 
				initialAnswer: class basicNew defaultPort greaseString.
			(port isNil or: [ port isEmpty or: [ port isAllDigits not ] ])
				ifFalse: [ adaptor := class port: port greaseInteger.
					self refreshAdaptors ] ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'JohanBrichau 6/18/2014 21:10'!
clearConfigurationCaches
	WAAdmin clearConfigurationCaches! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'JohanBrichau 6/18/2014 21:10'!
clearSessions
	WAAdmin clearSessions! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - accessing' stamp: 'JohanBrichau 6/18/2014 21:03'!
codecs
	^ GRCodec allCodecs asSortedCollection: [ :a :b | a name < b name ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - enablement' stamp: 'pmm 9/13/2013 15:03'!
disableAllButtons

	self toolbarModel startButton enabled: false.
	self toolbarModel stopButton enabled: false.
	self toolbarModel browseButton enabled: false! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - enablement' stamp: 'BenjaminVanRyseghem 9/13/2013 14:49'!
enableBrowseButton

	self toolbarModel browseButton enabled: true! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - enablement' stamp: 'BenjaminVanRyseghem 9/13/2013 14:49'!
enableStartButton

	self toolbarModel startButton enabled: true! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - enablement' stamp: 'BenjaminVanRyseghem 9/13/2013 14:49'!
enableStopButton

	self toolbarModel stopButton enabled: true! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - testing' stamp: 'TorstenBergmann 7/23/2014 17:50'!
hasSelectedAdaptor

	^adaptor notNil! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private - accessing' stamp: 'SvenVanCaekenberghe 5/24/2017 14:10'!
iconForAdaptor: anAdaptor

	^ anAdaptor isRunning 
		ifTrue:[ #seasideAdaptorRunningIcon asIcon ] 
		ifFalse:[ #easideAdaptorStoppedIcon asIcon ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'initialization' stamp: 'JohanBrichau 6/18/2014 20:56'!
initializeAdaptors
	self adapters: WAServerManager default adaptors! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'initialization' stamp: 'SvenVanCaekenberghe 5/24/2017 14:44'!
initializePresenter
	self initializeAdaptors.
	
	textModel 
		beForText; 
		enabled: false.
	
	listModel 
		whenSelectedItemChanged: [ :selection | adaptor := selection. self updateUIState ];
		displayBlock: [ :item | item class name , ' ' , item statusString ];
		icons: [ :item | self iconForAdaptor: item ];
		menu: [ :aMenu | self adaptorsMenu: aMenu ].

	self focusOrder
		add: listModel;
		add: toolbarModel;
		add: textModel.
	
	self disableAllButtons! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'initialization' stamp: 'SvenVanCaekenberghe 5/24/2017 14:08'!
initializeWidgets
	self instantiateModels: #(
		listModel IconListModel
		textModel TextModel
		toolbarModel WAServerAdapterToolbar).! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'accessing' stamp: 'pmm 9/13/2013 15:19'!
listModel
	^ listModel! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:45'!
refreshAdaptors
	self initializeAdaptors.
	self updateUIState ! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:49'!
removeAdaptor: anAdaptor
	anAdaptor isStopped
		ifTrue: [ anAdaptor unregister.
			self refreshAdaptors ]
		ifFalse: [ 
			UIManager default inform: 'Adaptor cannot be removed because it is still running. Please stop it first.' ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'JohanBrichau 6/18/2014 21:13'!
setEncodingFor: anAdaptor
	| codec |
	codec := UIManager default
		chooseFrom: (self codecs collect: [ :each | each name ]) 
		values: self codecs
		lines: #()
		title: 'Select encoding' translated.
	codec isNil
		ifTrue: [ ^ self ].
	anAdaptor codec: codec.! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:58'!
startAdaptor
	adaptor ifNotNil: [ adaptor start ].
	self updateUIState! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:58'!
stopAdaptor
	adaptor ifNotNil: [ adaptor stop ].
	self updateUIState! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'accessing' stamp: 'pmm 9/13/2013 15:20'!
textModel
	^ textModel! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'accessing' stamp: 'pmm 9/13/2013 15:20'!
toolbarModel
	^ toolbarModel! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 14:47'!
updateList
	| selectedIndex |
	selectedIndex := listModel selectedIndex.
	listModel updateList.
	listModel setSelectedIndex: selectedIndex
! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 15:59'!
updateUIState
	self updateList.
	
	self disableAllButtons.
	adaptor isNil
		ifTrue: [ 
			textModel text: '' ]
		ifFalse: [ 
			adaptor canStart
				ifTrue: [ self enableStartButton ].
			adaptor canStop
				ifTrue: [ self enableStopButton ].
			self enableBrowseButton.
			textModel text: self adaptorDescription ]! !

!WAPharoServerAdapterSpecBrowser methodsFor: 'api' stamp: 'SvenVanCaekenberghe 5/24/2017 15:23'!
windowIcon
	^ #seasideAdaptorRunningIcon asIcon! !

ComposableModel subclass: #WAServerAdapterToolbar
	instanceVariableNames: 'startButton stopButton browseButton refreshButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Pharo-Tools-Spec'!

!WAServerAdapterToolbar commentStamp: 'SvenVanCaekenberghe 5/24/2017 12:48' prior: 0!
WAServerAdaptorToolbar is used by WAPharoServerAdaptorSpecBrowser!

!WAServerAdapterToolbar class methodsFor: 'specs' stamp: 'SvenVanCaekenberghe 5/24/2017 15:37'!
defaultSpec

	<spec>
	^ SpecLayout composed
		newRow: [ :row | 
			row
				add: #(model startButton);
				add: #(model stopButton);
				add: #(model browseButton);
				add: #(model refreshButton) ];
		yourself! !

!WAServerAdapterToolbar class methodsFor: 'specs' stamp: 'StephanEggermont 8/31/2012 16:20'!
title
	^'Server adapter toolbar'! !

!WAServerAdapterToolbar methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:36'!
browseAdaptor
	self owner adaptor inspect! !

!WAServerAdapterToolbar methodsFor: 'accessing' stamp: 'StephanEggermont 8/31/2012 16:26'!
browseButton
	^browseButton! !

!WAServerAdapterToolbar methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 16:16'!
configureBrowseButton

	browseButton 
		label: 'Browse';
		help: 'Open an inspector on the selected adaptor object';
		enabled: true;
		action: [ self browseAdaptor ]! !

!WAServerAdapterToolbar methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 15:57'!
configureRefreshButton

	refreshButton 
		label: 'Refresh';
		help: 'Refresh the list of adaptors and their state';
		enabled: true;
		action: [ self refreshAdaptors ]! !

!WAServerAdapterToolbar methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 16:16'!
configureStartButton

	startButton 
		label: 'Start';
		help: 'Start the selected adaptor';
		enabled: true;
		action: [ self startAdaptor ]! !

!WAServerAdapterToolbar methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/24/2017 16:16'!
configureStopButton

	stopButton 
		label: 'Stop';
		help: 'Stop the selected adaptor';
		enabled: true;
		action: [ self stopAdaptor ]! !

!WAServerAdapterToolbar methodsFor: 'initialization' stamp: 'SvenVanCaekenberghe 5/24/2017 15:56'!
initializeWidgets

	self instantiateModels: #(
		startButton ButtonModel
		stopButton ButtonModel
		browseButton ButtonModel
		refreshButton ButtonModel).
	
	self configureStartButton.
	self configureStopButton.
	self configureBrowseButton.
	self configureRefreshButton.
	
	self focusOrder 
		add: startButton;
		add: stopButton;
		add: browseButton;
		add: refreshButton.
	! !

!WAServerAdapterToolbar methodsFor: 'actions' stamp: 'SvenVanCaekenberghe 5/24/2017 15:45'!
refreshAdaptors
	self owner refreshAdaptors 
	! !

!WAServerAdapterToolbar methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/24/2017 15:35'!
refreshButton
	^refreshButton ! !

!WAServerAdapterToolbar methodsFor: 'actions' stamp: 'JohanBrichau 7/11/2014 10:22'!
startAdaptor

	self owner startAdaptor! !

!WAServerAdapterToolbar methodsFor: 'accessing' stamp: 'StephanEggermont 8/31/2012 16:26'!
startButton
	^startButton! !

!WAServerAdapterToolbar methodsFor: 'actions' stamp: 'JohanBrichau 7/11/2014 10:22'!
stopAdaptor

	self owner stopAdaptor! !

!WAServerAdapterToolbar methodsFor: 'accessing' stamp: 'StephanEggermont 8/31/2012 16:26'!
stopButton
	^stopButton! !

!ThemeIcons methodsFor: '*seaside-pharo-tools-spec' stamp: 'JohanBrichau 6/14/2014 09:15'!
seasideAdaptorRunningIcon 
	^ icons
			at: #'seasideAdaptorRunningIcon'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self seasideAdaptorRunningIconContents readStream) ].! !

!ThemeIcons methodsFor: '*seaside-pharo-tools-spec' stamp: 'JohanBrichau 4/3/2016 09:30'!
seasideAdaptorRunningIconContents
	"Private - Method generated"
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAACXBIWXMAAAsTAAALEwEAmpwY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'! !

!ThemeIcons methodsFor: '*seaside-pharo-tools-spec' stamp: 'JohanBrichau 6/14/2014 09:15'!
seasideAdaptorStoppedIcon 
	^ icons
			at: #'seasideAdaptorStoppedIcon'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self seasideAdaptorStoppedIconContents readStream) ].! !

!ThemeIcons methodsFor: '*seaside-pharo-tools-spec' stamp: 'JohanBrichau 4/3/2016 10:17'!
seasideAdaptorStoppedIconContents
	"Private - Method generated"
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABt0lEQVR4XrVTTYtBURgemZp/
ME3zF8zimpSshik2iCmlWIiFhBW5GOUrHyFEp+ZKFkJpkO2sp9nzA5Tt+AHW77zvqZGPoRk1
b51O99z7PO/zvM+5F/9SPp/Pmk6nwev1imcRhMNhViwWAUnWZrP59s8EoiiyWq0GzWYTIpHI
Bx7Jvt8JgnCtUqmeaD9KgCDW6XQ4Ae1o6QXtsEAgsLDZbGAwGECtVktHCaLRaH84HEK9XofJ
ZALdbpcTZbNZcDqdoNfr16jgcQcUCoWsiUSCVavVBQGm0ykwxjbgTCYDlUqF1ABaeN4B48A+
qVur1eKAXq/Hd7KQz+f5oudGowE6ne51eya8UqnUvFwubzy3222QJAnojOJEVdDv9yEWi4FC
obj/0TcO6QHjG+RyuRWRjMdjPgMiI2IiwnekYH6gYK9kyWRyMRqNoFAo8M6DwYCrcDgcYLfb
KYHCyXsQj8dnZIHuQqlUArfbvXS5XODxeMBoNJIKSuHuKAEmMiPJFBt2fcMjOQGwc1Gr1a7o
HhzEuF1+v38WDAZJ7lKj0dzsW8R1edKCxWJ5N5lMa6VSKZz7Q8pxXf3mwy9Px//AHw3xPwAA
AABJRU5ErkJggg=='! !

!GRPackage class methodsFor: '*seaside-pharo-tools-spec' stamp: 'pmm 9/16/2013 10:37'!
seasidePharoToolsSpec
	^ self new
		name: 'Seaside-Pharo-Tools-Spec';
		description: 'Spec based server adapter browser for Pharo';
		addDependency: 'Seaside-Tools-Core';
		url: #seasideUrl;
		yourself! !
